# make.env
[![GitHub Workflow Status (event)](https://img.shields.io/github/workflow/status/smac89/make.env/Python%20application?event=push&label=tests&style=for-the-badge)](https://github.com/smac89/make.env/actions/workflows/python-app.yml)
[![PyPI](https://img.shields.io/pypi/v/make.env?style=for-the-badge)](https://pypi.org/project/make.env/)
[![GitHub](https://img.shields.io/github/license/smac89/make.env?style=for-the-badge)](https://github.com/smac89/make.env/blob/main/LICENSE)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/make.env?style=for-the-badge)](https://pypi.org/project/make.env/)

Infuses [GNU make](https://www.gnu.org/software/make/) with the ability to read .env files
